aboutsummaryrefslogtreecommitdiffstats
path: root/layoutlib_api
diff options
context:
space:
mode:
authorXavier Ducrohet <xav@android.com>2011-04-06 15:18:16 -0700
committerXavier Ducrohet <xav@android.com>2011-04-06 15:18:16 -0700
commitf593b81c5d76be05f4acc39f02a5c6e0df3ca877 (patch)
tree5d7a35e5e55595493f1c809894b1624393a49cae /layoutlib_api
parent79c8c93587295a899fa89da8b31fbfb008b59ee6 (diff)
downloadsdk-f593b81c5d76be05f4acc39f02a5c6e0df3ca877.zip
sdk-f593b81c5d76be05f4acc39f02a5c6e0df3ca877.tar.gz
sdk-f593b81c5d76be05f4acc39f02a5c6e0df3ca877.tar.bz2
Minor layoutlib api change for the data binding project callback.
Change-Id: Ib1b39938a459627a6ecf70556bdd6a99342ddf93
Diffstat (limited to 'layoutlib_api')
-rw-r--r--layoutlib_api/src/com/android/ide/common/rendering/api/IProjectCallback.java17
1 files changed, 9 insertions, 8 deletions
diff --git a/layoutlib_api/src/com/android/ide/common/rendering/api/IProjectCallback.java b/layoutlib_api/src/com/android/ide/common/rendering/api/IProjectCallback.java
index 99a1267..7368e50 100644
--- a/layoutlib_api/src/com/android/ide/common/rendering/api/IProjectCallback.java
+++ b/layoutlib_api/src/com/android/ide/common/rendering/api/IProjectCallback.java
@@ -99,13 +99,14 @@ public interface IProjectCallback {
* @param adapterCookie the view cookie for this particular view.
* @param itemRef the {@link ResourceReference} for the layout used by the adapter item.
* @param fullPosition the position of the item in the full list.
* @param typePosition the position of the item if only items of the same type are considered.
* If there is only one type of items, this is the same as <var>fullPosition</var>.
* @param fullChildPosition the position of the item in the full children list. This is only
* valid if the adapter view is an ExpandableListView.
* @param typeChildPosition the position of the child item if only items of the same type are
* considered. This is only valid if the adapter view is an ExpandableListView.
* If there is only one type of items, this is the same as <var>fullChildPosition</var>.
* @param viewRef The {@link ResourceReference} for the view we're trying to fill.
* @param ViewAttribute the attribute being queried.
* @param defaultValue the default value for this attribute. The object class matches the
@@ -116,8 +117,8 @@ public interface IProjectCallback {
*/
Object getAdapterItemValue(ResourceReference adapterView, Object adapterCookie,
ResourceReference itemRef,
- int fullPosition, int typePosition,
- int fullChildPosition, int typeChildPosition,
+ int fullPosition, int positionPerType,
+ int fullParentPosition, int parentPositionPerType,
ResourceReference viewRef, ViewAttribute viewAttribute, Object defaultValue);
/**
@@ -99,13 +99,14 @@ public interface IProjectCallback {
* @param itemRef the {@link ResourceReference} for the layout used by the adapter item.
* @param fullPosition the position of the item in the full list.
- * @param typePosition the position of the item if only items of the same type are considered.
- * If there is only one type of items, this is the same as <var>fullPosition</var>.
- * @param fullChildPosition the position of the item in the full children list. This is only
+ * @param positionPerType the position of the item if only items of the same type are
+ * considered. If there is only one type of items, this is the same as
+ * <var>fullPosition</var>.
+ * @param fullParentPosition the full position of the item's parent. This is only
* valid if the adapter view is an ExpandableListView.
@@ -99,13 +99,14 @@ public interface IProjectCallback {
* valid if the adapter view is an ExpandableListView.
- * @param typeChildPosition the position of the child item if only items of the same type are
- * considered. This is only valid if the adapter view is an ExpandableListView.
- * If there is only one type of items, this is the same as <var>fullChildPosition</var>.
+ * @param parentPositionPerType the position of the parent's item, only considering items
+ * of the same type. This is only valid if the adapter view is an ExpandableListView.
+ * If there is only one type of items, this is the same as <var>fullParentPosition</var>.
* @param viewRef The {@link ResourceReference} for the view we're trying to fill.
* @param ViewAttribute the attribute being queried.